autowisp.processing_steps.find_stars module — AutoWISP documentation

# autowisp.processing_steps.find_stars module

## Class Inheritance Diagram

Detect stars within calibrated image(s).

autowisp.processing_steps.find_stars.cleanup_interrupted(interrupted, configuration)

  Remove the extracted stars from the DR of the given calibrated image.

autowisp.processing_steps.find_stars.find_stars(image_collection, start_status, configuration, mark_start, mark_end)

  Extract sources from all input images and save them to DR files.

autowisp.processing_steps.find_stars.find_stars_single(image_fname, find_stars_in_image, srcextract_version, mark_start, mark_end)

  Find the stars in a single image.

autowisp.processing_steps.find_stars.main()

  Run the step from the command line.

autowisp.processing_steps.find_stars.parse_command_line(*args)

  Return the parsed command line arguments.